pub struct File {
pub mime: MimeType,
pub source: FileSource,
pub meta: Value,
}Expand description
A blob of non-text content attached to or emitted by a message.
Mimetype is the single source of truth for what the bytes mean.
source is how to retrieve them. meta is a free-form bag for
provider-specific annotations — consumers that don’t care ignore it.
Fields
mime: MimeTypesource: FileSourcemeta: ValueImplementations
Sourceimpl File
impl File
Sourcepub fn from_bytes(bytes: impl Into<Vec<u8>>) -> File
pub fn from_bytes(bytes: impl Into<Vec<u8>>) -> File
Construct a file from raw bytes, sniffing the mimetype from content.
Sourcepub fn from_bytes_with_mime(
bytes: impl Into<Vec<u8>>,
mime: impl Into<String>,
) -> File
pub fn from_bytes_with_mime( bytes: impl Into<Vec<u8>>, mime: impl Into<String>, ) -> File
Construct a file from raw bytes with an explicit mimetype.
pub fn from_path(path: impl AsRef<Path>) -> Result<File, Error>
Sourcepub fn from_url(
url: impl Into<String>,
mime: Option<&str>,
) -> Result<File, Box<dyn Error + Send + Sync>>
pub fn from_url( url: impl Into<String>, mime: Option<&str>, ) -> Result<File, Box<dyn Error + Send + Sync>>
Parse a URL. Mimetype defaults to application/octet-stream when
unknown — callers can supply a hint explicitly.
pub fn with_meta(self, meta: Value) -> File
pub fn is_image(&self) -> bool
pub fn is_audio(&self) -> bool
pub fn is_video(&self) -> bool
Sourcepub fn is_document(&self) -> bool
pub fn is_document(&self) -> bool
Anything that isn’t image/audio/video is treated as a document.