PartEnum

Enum PartEnum 

pub enum PartEnum {
    Reasoning(Reasoning),
    Text(Text),
    Tool(Tool),
    Structured(Value),
    File(File),
    Embeddings(Embeddings),
}

Variants



Reasoning(Reasoning)



Text(Text)



Tool(Tool)



Structured(Value)



File(File)



Embeddings(Embeddings)

Implementations

Source

impl PartEnum

pub fn from_function_call(fc: FunctionCall) -> PartEnum

Construct a PartEnum::Tool in the Pending state from a model-emitted call.

pub fn from_function_response(fr: FunctionResponse) -> PartEnum

Construct a PartEnum::Tool that is already Completed with the given response.

Used by deserialization shims and tests. Runtime flows should instead construct a Pending tool and call Tool::complete after execution.

pub fn tool(&self) -> Option<&Tool>

pub fn function_call(&self) -> Option<FunctionCall>

pub fn function_response(&self) -> Option<FunctionResponse>

pub fn text(&self) -> Option<Text>

pub fn reasoning(&self) -> Option<Reasoning>

pub fn embeddings(&self) -> Option<Embeddings>

pub fn structured(&self) -> Option<Value>

pub fn file(&self) -> Option<File>

pub fn from_reasoning(s: impl Into<String>) -> PartEnum

pub fn from_text(s: impl Into<String>) -> PartEnum

pub fn from_tool(tool: Tool) -> PartEnum

pub fn from_embeddings(embeddings: Embeddings) -> PartEnum

pub fn from_structured(value: Value) -> PartEnum

pub fn from_file(file: File) -> PartEnum