Messages

Struct Messages 

#[repr(transparent)]
pub struct Messages(pub Vec<Content>);

Tuple Fields

0: Vec<Content>

Implementations

Source

impl Messages

pub fn push(&mut self, content: Content) -> &mut Messages

Appends a Content to this Messages, merging parts when the last entry has the same role.

If the provided content has the same role as the last stored Content, its parts are appended to that last Content instead of adding a new entry.

Examples
let mut msgs = Messages(Vec::new());
msgs.push(content::from_system(vec!["first"]));
msgs.push(content::from_system(vec!["second"]));
assert_eq!(msgs.len(), 1);
pub fn extend(&mut self, messages: Messages) -> &mut Messages

Appends all Content items from messages into this Messages in order.

This moves the contained Content values out of messages and into self.

Examples
use crate::messages::content;
use crate::messages::Messages;

let mut a = Messages(vec![content::from_user(vec!["hello"])]);
let b = Messages(vec![content::from_system(vec!["system"])]);
a.extend(b);
assert_eq!(a.len(), 2);
pub fn len(&self) -> usize

Get the number of content items in the Messages.

Returns

The number of Content elements contained in this Messages.

Examples
use crate::messages::Messages;

let msgs = Messages(Vec::new());
assert_eq!(msgs.len(), 0);
pub fn is_empty(&self) -> bool

pub fn last(&self) -> Option<&Content>

Gets the last content item in the messages collection, if any.

Returns

Some(&Content) containing the last content item, or None if the collection is empty.

Examples
let msgs = from_user(vec!["hello"]);
assert!(msgs.last().is_some());